Installing agha
===============

Prerequisites
-------------

* Python 2.6+
* requests 2.2+

Installation
------------

Once you've downloaded and unpacked the agha source release,
enter the directory where the archive was unpacked, and run::

    python setup.py install

Note that you may need administrator/root privileges for this step, as
this command will by default attempt to install module to the Python
site-packages directory on your system.

For advanced options, please refer to the easy_install and/or the distutils
documentation.
